from typing import List

from audiostack.helpers.api_item import APIResponseItem
from audiostack.helpers.request_interface import RequestInterface
from audiostack.helpers.request_types import RequestTypes


class RecommendTag:
    FAMILY = "content"
    interface = RequestInterface(family=FAMILY)

    class Item(APIResponseItem):
        def __init__(self, response: dict) -> None:
            super().__init__(response)

            self.tags = self.data["tags"]

    @staticmethod
    def create(
        text: str, category: str, tags: List, number_of_results: int = 1
    ) -> Item:
        payload = {
            "text": text,
            "category": category,
            "tags": tags,
            "number_of_results": number_of_results,
        }
        r = RecommendTag.interface.send_request(
            rtype=RequestTypes.POST,
            route="recommend/tag",
            json=payload,
        )
        return RecommendTag.Item(r)


class RecommendMood:
    FAMILY = "content"
    interface = RequestInterface(family=FAMILY)

    class Item(APIResponseItem):
        def __init__(self, response: dict) -> None:
            super().__init__(response)

            self.moods = self.data["tags"]

    @staticmethod
    def create(text: str, number_of_results: int = 1) -> Item:
        payload = {"text": text, "number_of_results": number_of_results}
        r = RecommendMood.interface.send_request(
            rtype=RequestTypes.POST,
            route="recommend/mood",
            json=payload,
        )
        return RecommendMood.Item(r)


class RecommendTone:
    FAMILY = "content"
    interface = RequestInterface(family=FAMILY)

    class Item(APIResponseItem):
        def __init__(self, response: dict) -> None:
            super().__init__(response)

            self.tones = self.data["tags"]

    @staticmethod
    def create(text: str, number_of_results: int = 1) -> Item:
        payload = {"text": text, "number_of_results": number_of_results}
        r = RecommendTone.interface.send_request(
            rtype=RequestTypes.POST,
            route="recommend/tone",
            json=payload,
        )
        return RecommendTone.Item(r)



import os

import audiostack
from audiostack.production.sound import Sound

audiostack.api_base = os.environ.get("AUDIO_STACK_DEV_URL", "https://v2.api.audio")
audiostack.api_key = os.environ["AUDIO_STACK_DEV_KEY"]  # type: ignore


def test_list() -> None:
    sounds = Sound.Template.list()
    for s in sounds:
        assert isinstance(s, Sound.Template.Item)



import os
from typing import List
from unittest.mock import Mock, patch

import pytest

import audiostack
from audiostack.helpers.request_types import RequestTypes

audiostack.api_key = os.environ["AUDIO_STACK_DEV_KEY"]  # type: ignore


@pytest.fixture
def text() -> str:
    return "AudioStack’s technology seamlessly integrates into your product or workflow and cuts your audio production cycles to seconds while making your budgets go further."


@pytest.fixture
def category() -> str:
    return "my_custom_tags"


@pytest.fixture
def tags() -> List[str]:
    return ["happy", "sad", "valuable"]


@pytest.fixture
def number_of_results() -> int:
    return 2


@patch("audiostack.content.recommend.RecommendTag.Item")
@patch("audiostack.content.recommend.RecommendTag.interface.send_request")
def test_RecommendTag_create(
    mock_send_request: Mock,
    mock_tag_item: Mock,
    text: str,
    category: str,
    tags: list,
    number_of_results: int,
) -> None:
    response = audiostack.Content.RecommendTag.create(
        text=text, category=category, tags=tags, number_of_results=number_of_results
    )

    payload = {
        "text": text,
        "category": category,
        "tags": tags,
        "number_of_results": number_of_results,
    }

    mock_send_request.assert_called_once_with(
        rtype=RequestTypes.POST, route="recommend/tag", json=payload
    )
    mock_tag_item.assert_called_once_with(mock_send_request.return_value)

    assert response == mock_tag_item.return_value


def test_integration_tag(
    text: str, category: str, tags: list, number_of_results: int
) -> None:
    item = audiostack.Content.RecommendTag.create(
        text=text, category=category, tags=tags, number_of_results=number_of_results
    )
    assert item.status_code == 200
    assert hasattr(item, "tags")


@patch("audiostack.content.recommend.RecommendTone.Item")
@patch("audiostack.content.recommend.RecommendTone.interface.send_request")
def test_RecommendTone_create(
    mock_send_request: Mock,
    mock_tone_item: Mock,
    text: str,
    category: str,
    tags: list,
    number_of_results: int,
) -> None:
    response = audiostack.Content.RecommendTone.create(
        text=text, number_of_results=number_of_results
    )

    payload = {"text": text, "number_of_results": number_of_results}

    mock_send_request.assert_called_once_with(
        rtype=RequestTypes.POST, route="recommend/tone", json=payload
    )
    mock_tone_item.assert_called_once_with(mock_send_request.return_value)

    assert response == mock_tone_item.return_value


def test_integration_tone(text: str, number_of_results: int) -> None:
    item = audiostack.Content.RecommendTone.create(
        text=text, number_of_results=number_of_results
    )
    assert item.status_code == 200
    assert hasattr(item, "tones")


@patch("audiostack.content.recommend.RecommendMood.Item")
@patch("audiostack.content.recommend.RecommendMood.interface.send_request")
def test_RecommendMood_create(
    mock_send_request: Mock,
    mock_mood_item: Mock,
    text: str,
    category: str,
    tags: list,
    number_of_results: int,
) -> None:
    response = audiostack.Content.RecommendMood.create(
        text=text, number_of_results=number_of_results
    )

    payload = {"text": text, "number_of_results": number_of_results}

    mock_send_request.assert_called_once_with(
        rtype=RequestTypes.POST, route="recommend/mood", json=payload
    )
    mock_mood_item.assert_called_once_with(mock_send_request.return_value)

    assert response == mock_mood_item.return_value


def test_integration_mood(text: str, number_of_results: int) -> None:
    item = audiostack.Content.RecommendMood.create(
        text=text, number_of_results=number_of_results
    )
    assert item.status_code == 200
    assert hasattr(item, "moods")



from audiostack.content.file import File, Folder  # noqa: F401
from audiostack.content.media import Media  # noqa: F401
from audiostack.content.recommend import (  # noqa: F401
    RecommendMood,
    RecommendTag,
    RecommendTone,
)
from audiostack.content.script import Script  # noqa: F401
from audiostack.helpers.api_item import APIResponseItem


def list_projects() -> APIResponseItem:
    from audiostack.content.root_functions import Root

    return Root.list_projects()


def list_modules(projectName: str) -> APIResponseItem:
    from audiostack.content.root_functions import Root

    return Root.list_modules(projectName=projectName)


def generate(prompt: str, max_length: int = 100) -> APIResponseItem:
    from audiostack.content.root_functions import Root

    return Root.generate(prompt, max_length)



from typing import Any, List, Optional, Union

from audiostack.content.file import File
from audiostack.helpers.api_item import APIResponseItem
from audiostack.helpers.request_interface import RequestInterface
from audiostack.helpers.request_types import RequestTypes


class Suite:
    DENOISE_ENDPOINT = "suite/denoise"

    class FailedPipeline(Exception):
        pass

    interface = RequestInterface(family="production")

    class EvaluationItem(APIResponseItem):
        def __init__(self, response: dict) -> None:
            super().__init__(response)

    class PipelineInProgressItem(APIResponseItem):
        def __init__(self, response: dict) -> None:
            super().__init__(response)

            self.pipelineId = self.data["pipelineId"]

    class PipelineFinishedItem(PipelineInProgressItem):
        def __init__(self, response: dict) -> None:
            super().__init__(response)
            self.newFileIds = self.data["results"]["newFileIds"]
            self.inputFileIds = self.data["results"]["inputFileIds"]
            self.replacedFileIds = self.data["results"]["replacedFileIds"]

        def convert_new_files_to_items(self) -> List["File.Item"]:
            return [File.get(f["fileId"]) for f in self.newFileIds]

        def convert_replaced_files_to_items(self) -> List["File.Item"]:
            return [File.get(f["fileId"]) for f in self.replacedFileIds]

    @staticmethod
    def evaluate(
        fileId: str,
        preset: str = "",
        processes: list = [],
        text: str = "",
        scriptId: str = "",
        language: str = "en-US",
    ) -> EvaluationItem:
        if not (fileId):
            raise Exception("fileId should be supplied")
        if text and scriptId:
            raise Exception(
                "either text or scriptId or none should be supplied not both"
            )
        if not isinstance(processes, list):
            raise Exception("processes should be a list")
        if not isinstance(preset, str):
            raise Exception("preset should be a string")

        body = {
            "fileId": fileId,
            "preset": preset,
            "processes": processes,
            "language": language,
        }
        if text:
            body["text"] = text
        elif scriptId:
            body["scriptId"] = scriptId

        r = Suite.interface.send_request(
            rtype=RequestTypes.POST, route="suite/evaluate", json=body
        )

        while r["statusCode"] != 200 and r["statusCode"] != 404:  # TODO REVISE
            print("Response in progress please wait...")
            r = Suite.interface.send_request(
                rtype=RequestTypes.POST, route="suite/evaluate", json=body
            )

        return Suite.EvaluationItem(r)

    @staticmethod
    def separate(
        fileId: str, wait: bool = True
    ) -> Union["Suite.PipelineInProgressItem", "Suite.PipelineFinishedItem"]:

        body = {
            "fileId": fileId,
        }
        r = Suite.interface.send_request(
            rtype=RequestTypes.POST, route="suite/separate", json=body
        )
        item = Suite.PipelineInProgressItem(r)
        return Suite._poll(r, item.pipelineId) if wait else item

    @staticmethod
    def denoise(
        fileId: str, level: Optional[int] = None, wait: bool = True
    ) -> Union["Suite.PipelineInProgressItem", "Suite.PipelineFinishedItem"]:

        body = {"fileId": fileId, "level": level}
        r = Suite.interface.send_request(
            rtype=RequestTypes.POST, route=Suite.DENOISE_ENDPOINT, json=body
        )
        item = Suite.PipelineInProgressItem(r)
        return Suite._poll(r, item.pipelineId) if wait else item

    @staticmethod
    def _poll(r: Any, pipelineId: str) -> "Suite.PipelineFinishedItem":
        while r["statusCode"] == 202:
            r = Suite.interface.send_request(
                rtype=RequestTypes.GET,
                route="suite/pipeline",
                path_parameters=pipelineId,
            )

        status = r.get("data", {}).get("status", 200)
        if status > 400:
            msg = r.get("data", {}).get("message")
            errors = r.get("data", {}).get("errors")
            raise Suite.FailedPipeline(
                "pipeline failed: ", msg, "errors are as follows: ", ",".join(errors)
            )

        return Suite.PipelineFinishedItem(r)

    @staticmethod
    def get(pipelineId: str) -> "Suite.PipelineFinishedItem":
        r = Suite.interface.send_request(
            rtype=RequestTypes.GET, route="suite/pipeline", path_parameters=pipelineId
        )

        return Suite._poll(r, pipelineId)



import os

import audiostack
from audiostack.content.file import Folder

audiostack.api_base = os.environ.get("AUDIO_STACK_DEV_URL", "https://v2.api.audio")
audiostack.api_key = os.environ["AUDIO_STACK_DEV_KEY"]  # type: ignore

test_constants: dict = {}  #


def test_list() -> None:
    r = Folder.list(folder="")
    print(r)
    for fol in r.folders:
        print(fol)
    for fi in r.files:
        print(fi)


def test_create() -> None:

    r = Folder.delete(folder="__PYTHON_TEST", delete_files=True)
    r = Folder.create(name="__PYTHON_TEST")  # type: ignore
    print(r)


def test_delete() -> None:
    Folder.delete(folder="__PYTHON_TEST", delete_files=True)



sdk_version = "1.3.1"
api_base = "https://v2.api.audio"
api_key = None
assume_org_id = None
app_info = None


from audiostack import content as Content  # noqa: F401
from audiostack import delivery as Delivery  # noqa: F401
from audiostack import production as Production  # noqa: F401
from audiostack import speech as Speech  # noqa: F401
from audiostack.docs.docs import Documentation  # noqa: F401

billing_session = 0


def credits_used_in_this_session() -> float:
    return float("{:.2f}".format(billing_session))



from audiostack.helpers.api_item import APIResponseItem
from audiostack.helpers.request_interface import RequestInterface
from audiostack.helpers.request_types import RequestTypes


class Root:
    interface = RequestInterface(family="content")

    @staticmethod
    def list_projects() -> APIResponseItem:
        r = Root.interface.send_request(rtype=RequestTypes.GET, route="list_projects")
        return APIResponseItem(r)

    @staticmethod
    def list_modules(projectName: str) -> APIResponseItem:
        r = Root.interface.send_request(
            rtype=RequestTypes.GET,
            route="list_projects",
            query_parameters={"projectName": projectName},
        )
        return APIResponseItem(r)

    @staticmethod
    def generate(prompt: str, max_length: int = 100) -> APIResponseItem:
        r = Root.interface.send_request(
            rtype=RequestTypes.POST,
            route="generate",
            json={"prompt": prompt, "max_length": max_length},
        )
        return APIResponseItem(r)



from typing import Any, Optional

from audiostack.helpers.api_item import APIResponseItem
from audiostack.helpers.api_list import APIResponseList
from audiostack.helpers.request_interface import RequestInterface
from audiostack.helpers.request_types import RequestTypes


class TTS:
    interface = RequestInterface(family="speech")

    class Item(APIResponseItem):
        def __init__(self, response: dict) -> None:
            super().__init__(response)
            self.speechId = self.data["speechId"]

        def download(
            self, autoName: bool = False, fileName: str = "", path: str = "./"
        ) -> None:
            sections = self.data["sections"]
            for i, s in enumerate(sections):
                if autoName:
                    full_name = ""
                    for k, val in s["audience"].items():
                        full_name += f"{k}={val}~"

                    full_name = full_name[:-1] + ".wav"
                else:
                    if not fileName:
                        full_name = s["sectionName"] + ".wav"
                    else:
                        full_name = f"{fileName}_{i+1}_of_{len(sections)}.wav"
                RequestInterface.download_url(
                    s["url"], destination=path, name=full_name
                )

        def delete(self) -> APIResponseItem:
            return TTS.delete(self.speechId)

    class BytesItem(APIResponseItem):
        def __init__(self, response: dict) -> None:
            super().__init__(response)
            self.bytes = response["bytes"]

        # def download(self, autoName=False, fileName="default", path="./") -> None:
        #     with open("")

    class List(APIResponseList):
        def __init__(self, response: dict, list_type: Any) -> None:
            super().__init__(response, list_type)

        def resolve_item(self, list_type: str, item: Any) -> "TTS.Item":
            if list_type == "speechIds":
                return TTS.Item({"data": item})
            else:
                raise Exception()

    class Section:
        @staticmethod
        def create(
            sectionToProduce: Any,
            scriptId: str = "",
            scriptItem: Optional[Any] = None,
            voice: str = "",
            speed: float = 1.0,
            silencePadding: str = "",
            audience: dict = {},
            sections: dict = {},
            voiceIntelligence: bool = False,
            public: bool = False,
            sync: bool = True,
        ) -> "TTS.Item":
            # (start) no modify
            route = "tts/section"
            return TTS._create(**locals())
            # (end) modify

    @staticmethod
    def preview(text: str, voice: str) -> "TTS.BytesItem":
        body = {"text": text, "voice": voice}
        r = TTS.interface.send_request(
            rtype=RequestTypes.POST, route="tts/preview", json=body
        )
        return TTS.BytesItem(r)

    @staticmethod
    def reduce(speechId: str, targetLength: str, sectionId: str = "") -> "TTS.Item":
        body = {
            "speechId": speechId,
            "targetLength": targetLength,
            "sectionId": sectionId,
        }
        r = TTS.interface.send_request(
            rtype=RequestTypes.POST, route="tts/reduce", json=body
        )
        print(r)
        return TTS.Item(r)

    @staticmethod
    def remove_padding(
        speechId: str,
        minSilenceDuration: float = 1.5,
        silenceThreshold: float = 0.001,
        position: str = "end",
        sectionId: str = "",
    ) -> "TTS.Item":
        body = {
            "speechId": speechId,
            "minSilenceDuration": minSilenceDuration,
            "silenceThreshold": silenceThreshold,
            "position": position,
            "sectionId": sectionId,
        }
        r = TTS.interface.send_request(
            rtype=RequestTypes.POST, route="tts/remove_padding", json=body
        )
        print(r)
        return TTS.Item(r)

    @staticmethod
    def annotate(
        speechId: str,
        scriptReference: str = "",
        languageCode: str = "",
        continuousRecognition: bool = False,
    ) -> dict:

        body = {
            "speechId": speechId,
            "scriptReference": scriptReference,
            "language_code": languageCode,
            "continuous_recognition": continuousRecognition,
        }
        r = TTS.interface.send_request(
            rtype=RequestTypes.POST, route="tts/annotate", json=body
        )
        print(r)
        return r

    @staticmethod
    def create(
        scriptId: str = "",
        scriptItem: Optional[Any] = None,
        voice: str = "",
        speed: float = 1.0,
        silencePadding: str = "",
        audience: dict = {},
        sections: dict = {},
        voiceIntelligence: bool = False,
        public: bool = False,
        sync: bool = True,
    ) -> "TTS.Item":
        # (start) no modify
        route = "tts"
        return TTS._create(**locals())
        # (end) modify

    @staticmethod
    def get(speechId: str, public: bool = False) -> "TTS.Item":
        r = TTS.interface.send_request(
            rtype=RequestTypes.GET,
            route="tts",
            path_parameters=speechId,
            query_parameters={"public": public},
        )
        return TTS.Item(r)

    @staticmethod
    def delete(speechId: str) -> APIResponseItem:
        r = TTS.interface.send_request(
            rtype=RequestTypes.DELETE, route="tts", path_parameters=speechId
        )
        return APIResponseItem(r)

    @staticmethod
    def list(
        projectName: str = "",
        moduleName: str = "",
        scriptName: str = "",
        scriptId: str = "",
    ) -> "TTS.List":
        query_params = {
            "projectName": projectName,
            "moduleName": moduleName,
            "scriptName": scriptName,
            "scriptId": scriptId,
        }
        r = TTS.interface.send_request(
            rtype=RequestTypes.GET, route="tts", query_parameters=query_params
        )
        return TTS.List(r, list_type="speechIds")

    @staticmethod
    def _create(
        route: str,
        scriptId: str = "",
        scriptItem: Optional[Any] = None,
        voice: str = "",
        speed: float = 1.0,
        silencePadding: str = "",
        audience: dict = {},
        sections: dict = {},
        voiceIntelligence: bool = False,
        public: bool = False,
        sync: bool = True,
        sectionToProduce: str = "",
    ) -> "TTS.Item":
        if scriptId and scriptItem:
            raise Exception("scriptId or scriptItem should be supplied not both")
        if not (scriptId or scriptItem):
            raise Exception("scriptId or scriptItem should be supplied")

        if scriptItem:
            scriptId = scriptItem.scriptId

        if not isinstance(voice, str):
            raise Exception("voice argument should be a string")
        if not isinstance(silencePadding, str):
            raise Exception("silencePadding argument should be a string")

        body = {
            "scriptId": scriptId,
            "voice": voice,
            "speed": speed,
            "silencePadding": silencePadding,
            "audience": audience,
            "sections": sections,
            "voiceIntelligence": voiceIntelligence,
            "public": public,
            "sync": sync,
        }
        if sectionToProduce:
            body["sectionToProduce"] = sectionToProduce

        r = TTS.interface.send_request(rtype=RequestTypes.POST, route="tts", json=body)
        while r["statusCode"] == 202:
            print("Response in progress please wait...")
            r = TTS.interface.send_request(
                rtype=RequestTypes.GET,
                route=route,
                path_parameters=r["data"]["speechId"],
                query_parameters={"public": public},
            )

        return TTS.Item(r)



import json
from typing import Union


class APIResponseItem:
    def __init__(self, response: dict) -> None:
        self.response = response

        # extra specific fields
        self.status_code = response.get("statusCode", 0)
        self.data = response.get("data", {})
        self.message = response.get("message", "")
        self.meta = response.get("meta", {})
        self.bytes = response.get("bytes", None)

    def print_response(self, indent: int = 0) -> Union[dict, str]:
        if indent:
            return json.dumps(self.response, indent=indent)
        else:
            return self.response

    def __str__(self) -> str:
        if self.bytes:
            return "bytes object"
        else:
            return json.dumps(self.response)



from typing import Any, Optional

from audiostack.helpers.api_item import APIResponseItem
from audiostack.helpers.request_interface import RequestInterface
from audiostack.helpers.request_types import RequestTypes


class Video:
    interface = RequestInterface(family="delivery")

    class Item(APIResponseItem):
        def __init__(self, response: dict) -> None:
            super().__init__(response)
            self.url = self.data["url"]
            self.format = self.data["format"]

        def download(self, fileName: str = "default", path: str = "./") -> None:
            full_name = f"{fileName}.{self.format}"
            RequestInterface.download_url(self.url, destination=path, name=full_name)

    @staticmethod
    def create(
        productionId: str = "",
        productionItem: Optional[Any] = None,
        public: bool = False,
    ) -> Item:

        if productionId and productionItem:
            raise Exception(
                "productionId or productionItem should be supplied not both"
            )
        if not (productionId or productionItem):
            raise Exception("productionId or productionItem should be supplied")

        if productionItem:
            try:
                productionId = productionItem.productionId
            except Exception:
                raise Exception(
                    "supplied productionItem is missing an attribute, productionItem should be type object and a response from Production.Mix"
                )
        elif productionId:
            if not isinstance(productionId, str):
                raise Exception("supplied productionId should be a uuid string.")

        body = {
            "productionId": productionId,
            "public": public,
        }
        r = Video.interface.send_request(
            rtype=RequestTypes.POST, route="video", json=body
        )

        while r["statusCode"] == 202:
            videoId = r["data"]["videoId"]
            r = Video.interface.send_request(
                rtype=RequestTypes.GET, route="video", path_parameters=videoId
            )
        return Video.Item(r)



import os
from typing import Any

from audiostack.helpers.api_item import APIResponseItem
from audiostack.helpers.api_list import APIResponseList
from audiostack.helpers.request_interface import RequestInterface
from audiostack.helpers.request_types import RequestTypes


class File:
    FAMILY = "content"
    interface = RequestInterface(family=FAMILY)

    class Item(APIResponseItem):
        def __init__(self, response: dict) -> None:
            super().__init__(response)
            self.fileId = self.data["fileId"]
            self.filePath = self.data["filePath"]
            self.url = self.data.get("url", None)

        def delete(self) -> APIResponseItem:
            return File.delete(self.fileId)

        def download(self, fileName: str = "", path: str = "./") -> None:
            if not fileName:
                fileName = self.filePath.split("/")[-1]
            RequestInterface.download_url(self.url, destination=path, name=fileName)

    class List(APIResponseList):
        def __init__(self, response: dict, list_type: str) -> None:
            super().__init__(response, list_type)

        def resolve_item(self, list_type: str, item: Any) -> "File.Item":
            if list_type == "items" or list_type == "files":
                return File.Item({"data": item})
            else:
                raise Exception()

    @staticmethod
    def create(
        localPath: str,
        uploadPath: str,
        fileType: str,
        category: str = "",
        tags: list = [],
        metadata: dict = {},
    ) -> Item:
        if not os.path.isfile(localPath):
            raise Exception("Supplied file does not eixst")

        if not uploadPath or not localPath:
            raise Exception(
                "Please supply a localPath (path to your local file) and an uploadPath (path to where youd like this to be saved)"
            )

        data = {
            "filePath": uploadPath,
            "fileType": fileType,
            "source": "pythonSDK",
            "category": category,
            "tags": tags,
            "metadata": metadata,
        }

        r = File.interface.send_request(
            rtype=RequestTypes.POST,
            route="file/create-upload-url",
            json=data,
        )
        response = APIResponseItem(r)
        url = response.data["fileUploadUrl"]
        fileId = response.data["fileId"]

        File.interface.send_upload_request(local_path=localPath, upload_url=url)
        return File.get(fileId)

    @staticmethod
    def transfer(
        url: str,
        uploadPath: str,
        category: str = "",
        tags: list = [],
        metadata: dict = {},
    ) -> Item:

        data = {
            "filePath": uploadPath,
            "url": url,
            "category": category,
            "tags": tags,
            "metadata": metadata,
        }

        r = File.interface.send_request(
            rtype=RequestTypes.PUT,
            route="file/transfer-file",
            json=data,
        )
        response = APIResponseItem(r)
        return File.get(response.data["fileId"])

    @staticmethod
    def modify(
        fileId: str,
        filePath: str = "",
        category: str = "",
        tags: list = [],
        metadata: dict = {},
    ) -> Item:

        data = {
            "filePath": filePath,
            "category": category,
            "tags": tags,
            "metadata": metadata,
        }

        File.interface.send_request(
            rtype=RequestTypes.PATCH,
            route=f"file/id/{fileId}",
            json=data,
        )
        return File.get(fileId)

    @staticmethod
    def get(fileId: str) -> Item:
        r = File.interface.send_request(
            rtype=RequestTypes.GET, route="file/id", path_parameters=fileId
        )
        return File.Item(r)

    @staticmethod
    def delete(fileId: str) -> APIResponseItem:
        r = File.interface.send_request(
            rtype=RequestTypes.DELETE, route="file/id", path_parameters=fileId
        )
        return APIResponseItem(r)

    @staticmethod
    def search(
        path: str = "",
        source: str = "",
        tags: list = [],
        name: str = "",
        fileType: str = "",
        category: str = "",
        sortBy: str = "",
    ) -> List:
        queries = {
            "path": path,
            "source": source,
            "tags": tags,
            "name": name,
            "fileType": fileType,
            "category": category,
            "soryBy": sortBy,
        }
        r = File.interface.send_request(
            rtype=RequestTypes.GET, route="file/search", query_parameters=queries
        )
        return File.List(r, list_type="items")


class Folder:
    FAMILY = "content"
    interface = RequestInterface(family=FAMILY)

    class Item(APIResponseItem):
        def __init__(self, response: dict) -> None:
            super().__init__(response)
            self.folders = Folder.List(response, list_type="folders")
            self.files = File.List(response, list_type="files")

    class List(APIResponseList):
        def __init__(self, response: dict, list_type: str) -> None:
            super().__init__(response, list_type)

        def resolve_item(self, list_type: str, item: Any) -> dict:
            if list_type == "folders":
                return {"data": item}
            else:
                raise Exception()

    @staticmethod
    def create(name: Any) -> APIResponseItem:

        r = File.interface.send_request(
            rtype=RequestTypes.POST,
            route="folder",
            json={"folder": name},
        )
        return APIResponseItem(r)

    @staticmethod
    def list(folder: str) -> "Folder.Item":
        r = File.interface.send_request(
            rtype=RequestTypes.GET, route="folder", query_parameters={"folder": folder}
        )
        return Folder.Item(r)

    @staticmethod
    def delete(folder: str, delete_files: bool = False) -> APIResponseItem:
        r = File.interface.send_request(
            rtype=RequestTypes.DELETE,
            route="folder",
            query_parameters={"folder": folder, "forceDelete": delete_files},
        )
        return APIResponseItem(r)



from typing import Any, Union

from audiostack.helpers.api_item import APIResponseItem
from audiostack.helpers.api_list import APIResponseList
from audiostack.helpers.request_interface import RequestInterface
from audiostack.helpers.request_types import RequestTypes


class Diction:
    interface = RequestInterface(family="speech/diction")

    class Item(APIResponseItem):
        def __init__(self, response: dict) -> None:
            super().__init__(response)
            self.lang = self.data["lang"]
            self.words = self.data["words"]
            self.wordCategory = self.data.get("wordCategory", "")
            self.content = self.data.get("content", "")

    class Word(APIResponseItem):
        def __init__(self, response: dict) -> None:
            super().__init__(response)
            self.inputs = self.data["inputs"]
            self.replacements = self.data["replacements"]

    class List(APIResponseList):
        def __init__(self, response: dict, list_type: str) -> None:
            super().__init__(response, list_type)

        def resolve_item(
            self, list_type: str, item: Any
        ) -> Union["Diction.Item", "Diction.Word"]:
            if list_type == "dictionaries":
                return Diction.Item({"data": item})
            elif list_type == "words":
                return Diction.Word({"data": item})
            else:
                raise Exception()

    @staticmethod
    def list() -> "Diction.List":
        r = Diction.interface.send_request(rtype=RequestTypes.GET, route="")
        return Diction.List(r, "dictionaries")

    class Custom:
        @staticmethod
        def list() -> "Diction.List":
            r = Diction.interface.send_request(rtype=RequestTypes.GET, route="custom")
            return Diction.List(r, "dictionaries")

        @staticmethod
        def create_word(
            word: str,
            replacement: str,
            lang: str = "global",
            specialization: str = "default",
            contentType: str = "basic",
        ) -> "Diction.Word":
            body = {
                "word": word,
                "replacement": replacement,
                "lang": lang,
                "specialization": specialization,
                "contentType": contentType,
            }

            r = Diction.interface.send_request(
                rtype=RequestTypes.PUT, route="custom/item", json=body
            )
            return Diction.Word(r)

        @staticmethod
        def list_words(lang: str) -> "Diction.List":
            r = Diction.interface.send_request(
                rtype=RequestTypes.GET,
                route="custom/items",
                query_parameters={"lang": lang},
            )
            return Diction.List(r, "words")

        @staticmethod
        def delete_word(
            lang: str, word: str, specialization: str = ""
        ) -> APIResponseItem:
            query = {"lang": lang, "word": word, "specialization": specialization}
            r = Diction.interface.send_request(
                rtype=RequestTypes.DELETE, route="custom/item", query_parameters=query
            )
            return APIResponseItem(r)



from typing import Any

from audiostack.helpers.api_item import APIResponseItem
from audiostack.helpers.api_list import APIResponseList
from audiostack.helpers.request_interface import RequestInterface
from audiostack.helpers.request_types import RequestTypes


class Script:
    FAMILY = "content"
    interface = RequestInterface(family=FAMILY)

    class Item(APIResponseItem):
        def __init__(self, response: dict) -> None:
            super().__init__(response)

            self.scriptId = self.data["scriptId"]
            self.projectName = self.data["projectName"]
            self.moduleName = self.data["moduleName"]
            self.scriptName = self.data["scriptName"]
            self.scriptText = self.data["scriptText"]

        def update(self, scriptText: str) -> "Script.Item":
            return Script.update(scriptId=self.scriptId, scriptText=scriptText)

        def delete(self) -> APIResponseItem:
            return Script.delete(self.scriptId)

    class List(APIResponseList):
        def __init__(self, response: dict, list_type: str) -> None:
            super().__init__(response, list_type)

        def resolve_item(self, list_type: str, item: Any) -> "Script.Item":
            if list_type == "scripts":
                return Script.Item({"data": item})
            else:
                raise Exception()

    @staticmethod
    def create(
        scriptText: str,
        projectName: str = "",
        moduleName: str = "",
        scriptName: str = "",
        metadata: dict = {},
    ) -> Item:
        body = {
            "scriptText": scriptText,
            "projectName": projectName,
            "moduleName": moduleName,
            "scriptName": scriptName,
            "metadata": metadata,
        }

        r = Script.interface.send_request(
            rtype=RequestTypes.POST, route="script", json=body
        )
        return Script.Item(r)

    @staticmethod
    def generate_advert(
        product_name: str,
        product_description: str,
        mood: str = "",
        tone: str = "",
        thirdPerson: bool = True,
        adLength: int = 30,
    ) -> APIResponseItem:
        body = {
            "productName": product_name,
            "productDescription": product_description,
            "mood": mood,
            "tone": tone,
            "thirdPerson": thirdPerson,
            "adLength": adLength,
        }

        r = Script.interface.send_request(
            rtype=RequestTypes.POST, route="generate/advert", json=body
        )
        return APIResponseItem(r)

    @staticmethod
    def get(scriptId: str, version: str = "", previewWithVoice: str = "") -> Item:
        path_params = f"{scriptId}/{version}" if version else scriptId
        if previewWithVoice:
            query_params = {
                "preview": bool(previewWithVoice),
                "voice": previewWithVoice,
            }
        else:
            query_params = {}

        r = Script.interface.send_request(
            rtype=RequestTypes.GET,
            route="script",
            path_parameters=path_params,
            query_parameters=query_params,
        )
        return Script.Item(r)

    @staticmethod
    def delete(scriptId: str, version: str = "") -> APIResponseItem:
        path_params = f"{scriptId}/{version}" if version else scriptId
        r = Script.interface.send_request(
            rtype=RequestTypes.DELETE, route="script", path_parameters=path_params
        )
        return APIResponseItem(r)

    @staticmethod
    def update(scriptId: str, scriptText: str, version: str = "") -> Item:
        body = {"scriptId": scriptId, "scriptText": scriptText, "version": version}
        r = Script.interface.send_request(
            rtype=RequestTypes.PUT, json=body, route="script"
        )
        return Script.Item(r)

    @staticmethod
    def list(
        projectName: str = "",
        moduleName: str = "",
        scriptName: str = "",
        scriptId: str = "",
    ) -> List:
        query_params = {
            "projectName": projectName,
            "moduleName": moduleName,
            "scriptName": scriptName,
            "scriptId": scriptId,
        }
        r = Script.interface.send_request(
            rtype=RequestTypes.GET, route="scripts", query_parameters=query_params
        )
        return Script.List(r, list_type="scripts")



import os

import audiostack

audiostack.api_base = os.environ.get("AUDIO_STACK_DEV_URL", "https://v2.api.audio")
audiostack.api_key = os.environ["AUDIO_STACK_DEV_KEY"]  # type: ignore

test_constants = {}  # type: dict


def test_video() -> None:
    script = audiostack.Content.Script.create(scriptText="hello sam")

    speech = audiostack.Speech.TTS.create(scriptItem=script, voice="sara")

    mix = audiostack.Production.Mix.create(speechItem=speech)
    print(mix)

    video = audiostack.Delivery.Video.create(
        productionItem=mix,
        public=True,
    )
    print(video)
